Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1932)

Unified Diff: Source/platform/heap/Heap.h

Issue 1149943003: Oilpan: Rename weak callback related methods (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/platform/heap/Heap.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/platform/heap/Heap.h
diff --git a/Source/platform/heap/Heap.h b/Source/platform/heap/Heap.h
index 533fc3ebb40222234b360bbae9db214d689fadbf..5073e373974a91edf5c80fc6211775a2b5d27a31 100644
--- a/Source/platform/heap/Heap.h
+++ b/Source/platform/heap/Heap.h
@@ -859,13 +859,13 @@ public:
// the containerObject can be the same thing, but the containerObject is
// constrained to be on the heap, since the heap is used to identify the
// correct thread.
- static void pushWeakPointerCallback(void* closure, void* containerObject, WeakPointerCallback);
+ static void pushThreadLocalWeakCallback(void* closure, void* containerObject, WeakPointerCallback);
sof 2015/05/22 09:07:48 Wouldn't it make sense to rename WeakPointerCallba
haraken 2015/05/22 10:07:08 Done.
// Similar to the more general pushWeakPointerCallback, but cell
// pointer callbacks are added to a static callback work list and the weak
// callback is performed on the thread performing garbage collection. This
// is OK because cells are just cleared and no deallocation can happen.
- static void pushWeakCellPointerCallback(void** cell, WeakPointerCallback);
+ static void pushGlobalWeakCallback(void** cell, WeakPointerCallback);
// Pop the top of a marking stack and call the callback with the visitor
// and the object. Returns false when there is nothing more to do.
@@ -879,7 +879,7 @@ public:
// Remove an item from the weak callback work list and call the callback
// with the visitor and the closure pointer. Returns false when there is
// nothing more to do.
- static bool popAndInvokeWeakPointerCallback(Visitor*);
+ static bool popAndInvokeGlobalWeakCallback(Visitor*);
// Register an ephemeron table for fixed-point iteration.
static void registerWeakTable(void* containerObject, EphemeronCallback, EphemeronCallback);
@@ -1014,7 +1014,7 @@ private:
static Visitor* s_markingVisitor;
static CallbackStack* s_markingStack;
static CallbackStack* s_postMarkingCallbackStack;
- static CallbackStack* s_weakCallbackStack;
+ static CallbackStack* s_globalWeakCallbackStack;
static CallbackStack* s_ephemeronStack;
static HeapDoesNotContainCache* s_heapDoesNotContainCache;
static bool s_shutdownCalled;
@@ -859,13 +859,13 @@ public:
sof 2015/05/22 09:07:48 Wouldn't it make sense to rename WeakPointerCallba
haraken 2015/05/22 10:07:08 Done.
- // Similar to the more general pushWeakPointerCallback, but cell
+ // Similar to the more general pushThreadLocalWeakCallback, but cell
// pointer callbacks are added to a static callback work list and the weak
// callback is performed on the thread performing garbage collection. This
« no previous file with comments | « no previous file | Source/platform/heap/Heap.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698